@@ -38,7 +38,7 @@ int main(int argc, char *argv[])
     a.setApplicationName("storageusage");
     w.initialize();
 
-#ifndef Q_WS_HILDON
+#ifndef Q_WS_MAEMO_5
     w.resize(800, 480);
     w.show();
 #else
