@@ -38,9 +38,9 @@ protected:
     virtual void run();
 
 signals:
-    void folderFound(QString strFolder);
+    void folderFound(const QString& strFolder);
     void folderScanned();
-    void fileFound(QString strFilename, QString strFilePath, qint64 size);
+    void fileFound(const QString& strFilename, const QString& strFilePath, qint64 size);
 
     void progressMaximum(int maxValue);
     void progressValue(QString strText, int value);
