@@ -61,6 +61,9 @@ public slots:
     void onProgressMaximum(int maxValue);
     void onProgressValue(QString strText, int value);
 
+protected:
+    virtual void closeEvent(QCloseEvent* event);
+
 private:
     QString m_strFolder;             ///< The folder to be scanned
     QTreeView* m_pTreeWidget;        ///< Contains the directory tree
