@@ -95,10 +95,7 @@ QStandardItem* CUsageGrid::pickItem(QStandardItem* pItem, QPoint pos)
                 }
             }
         }
-        else
-        {
-            return pItem;
-        }
+        return pItem;
     }
     return NULL;
 }
@@ -153,7 +150,7 @@ void CUsageGrid::createGrid(QStandardItem* pItem, bool bRecursive)
     QFont font;
     font.setPixelSize(9);
     painter.setFont(font);
-    drawGrid(painter, pItem, rect(), bRecursive);
+    drawGrid(painter, pItem, rect(), bRecursive, 0);
 
     // qDebug() << "Create grid time: " << timer.elapsed();
 }
@@ -166,8 +163,9 @@ void CUsageGrid::createGrid(QStandardItem* pItem, bool bRecursive)
 ** \param pItem The currently drawn item.
 ** \param rect The item's rectangle
 ** \param bRecursive If true the items are scanned recursively.
+** \param level The current recurse level
 */
-void CUsageGrid::drawGrid(QPainter& painter, QStandardItem* pItem, const QRectF& rect, bool bRecursive)
+void CUsageGrid::drawGrid(QPainter& painter, QStandardItem* pItem, const QRectF& rect, bool bRecursive, int level)
 {
     if (pItem)
     {
@@ -204,7 +202,7 @@ void CUsageGrid::drawGrid(QPainter& painter, QStandardItem* pItem, const QRectF&
             qreal h = rect.height();
             qreal w = rect.width();
 
-            if (pItem->rowCount() == 0 || (rect.width() < 2 && rect.height() < 2) || (!bRecursive && pItem->parent()))
+            if (pItem->rowCount() == 0 || (rect.width() < 2 && rect.height() < 2) || (!bRecursive && pItem->parent()) || level > 3)
             {
                 QString strName = pItem->data(Qt::DisplayRole).toString();
 
@@ -219,7 +217,7 @@ void CUsageGrid::drawGrid(QPainter& painter, QStandardItem* pItem, const QRectF&
                 gradient.setSpread(QGradient::PadSpread);
                 painter.fillRect(rect, gradient);
 #endif
-                if ((!bRecursive || pItem->data(TypeRole).toInt() == TYPE_FILE) && (rect.width() > 10 && rect.height() > 5))
+                if (rect.width() > 10 && rect.height() > 5)
                 {
                     painter.setPen(Qt::black);
                     painter.drawText(rect, Qt::AlignCenter, strName);
@@ -247,7 +245,7 @@ void CUsageGrid::drawGrid(QPainter& painter, QStandardItem* pItem, const QRectF&
 
                     newColumnTotal += size;
 
-                    drawGrid(painter, pItem->child(i), QRectF(x, y, w, h), bRecursive);
+                    drawGrid(painter, pItem->child(i), QRectF(x, y, w, h), bRecursive, level + 1);
                 }
             }
         }
